@@ -1,13 +1,3 @@
-( cd opt/kde/share/doc/HTML/fi/khangman ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/khangman ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/kfind ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/kfind ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/khelpcenter/glossary ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/khelpcenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/ksirtet ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/ksirtet ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf qpl-license.html )
@@ -44,6 +34,8 @@
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/grad.png grad.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf kde-web.css )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/kde-web.css kde-web.css )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf kde_logo_bg.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/kde_logo_bg.png kde_logo_bg.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/lgpl-license.html lgpl-license.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf doxygen.css )
@@ -58,12 +50,16 @@
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf appheader.html )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf doctop1.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/doctop1.png doctop1.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf doctop2.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/doctop2.png doctop2.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf shadow.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/shadow.png shadow.png )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf kde_logo.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf fdl-license.html )
@@ -94,13 +90,3 @@
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/web-docbottom.png web-docbottom.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf artistic-license.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/artistic-license.html artistic-license.html )
-( cd opt/kde/share/doc/HTML/fi/klines ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/klines ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/kpoker ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/kpoker ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/ksnake ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/ksnake ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/klickety ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/klickety ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
-( cd opt/kde/share/doc/HTML/fi/atlantik ; rm -rf common )
-( cd opt/kde/share/doc/HTML/fi/atlantik ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
